Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ReadYAMLConfig ¶
ReadYAMLConfig reads a YAML configuration file and unmarshals it into the provided interface config parameter should be a pointer to a struct that matches the YAML structure
Types ¶
type EndpointConfig ¶ added in v0.10.0
type Service ¶ added in v0.10.0
type Service interface {
Init(ServiceConfig) error
RegisterEndpoint(*Endpoint) error
Start() error
}
type ServiceConfig ¶ added in v0.10.0
Click to show internal directories.
Click to hide internal directories.